@@ -3,14 +3,12 @@
 # Copyright (c) CERN, 2021.                 #
 # ######################################### #
 
-from .general import _pkg_root
+from .general import _pkg_root, _print
 from .particles import Particles, ParticlesBase, pmass
 
 from .build_particles import build_particles
 from .matched_gaussian import generate_matched_gaussian_bunch
 
-from .linear_normal_form import compute_linear_normal_form
-
 from .transverse_generators import generate_2D_polar_grid
 from .transverse_generators import generate_2D_uniform_circular_sector
 from .transverse_generators import generate_2D_pencil
